@@ -113,12 +113,12 @@ void AdvSceneSwitcher::on_startupBehavior_currentIndexChanged(int index)
 		static_cast<SwitcherData::StartupBehavior>(index);
 }
 
-void AdvSceneSwitcher::on_logLevel_currentIndexChanged(int value)
+void AdvSceneSwitcher::on_logLevel_currentIndexChanged(int idx)
 {
 	if (loading) {
 		return;
 	}
-	switcher->logLevel = static_cast<SwitcherData::LogLevel>(value);
+	SetLogLevel(static_cast<LogLevel>(ui->logLevel->itemData(idx).toInt()));
 }
 
 void AdvSceneSwitcher::on_autoStartEvent_currentIndexChanged(int index)
@@ -163,7 +163,7 @@ void AdvSceneSwitcher::closeEvent(QCloseEvent *)
 	switcher->windowSize = this->size();
 	switcher->macroListMacroEditSplitterPosition =
 		ui->macroListMacroEditSplitter->sizes();
-	MacroSelectionAboutToChange(); // Trigger saving of splitter states
+	ui->macroEdit->SetMacro(nullptr); // Trigger saving of splitter states
 
 	obs_frontend_save();
 }
@@ -205,6 +205,16 @@ void AdvSceneSwitcher::on_disableComboBoxFilter_stateChanged(int state)
 	FilterComboBox::SetFilterBehaviourEnabled(!state);
 }
 
+void AdvSceneSwitcher::on_disableMacroWidgetCache_stateChanged(int state)
+{
+	if (loading) {
+		return;
+	}
+
+	switcher->disableMacroWidgetCache = state;
+	MacroSegmentList::SetCachingEnabled(!state);
+}
+
 void AdvSceneSwitcher::on_warnPluginLoadFailure_stateChanged(int state)
 {
 	if (loading) {
@@ -275,12 +285,15 @@ static bool containsSensitiveData(obs_data_t *data)
 		obs_data_get_array(data, "twitchConnections");
 	OBSDataArrayAutoRelease websocketConnections =
 		obs_data_get_array(data, "websocketConnections");
+	OBSDataArrayAutoRelease mqttConnections =
+		obs_data_get_array(data, "mqttConnections");
 
 	auto isNotEmpty = [](obs_data_array *array) {
 		return obs_data_array_count(array) > 0;
 	};
 
-	return isNotEmpty(twitchTokens) || isNotEmpty(websocketConnections);
+	return isNotEmpty(twitchTokens) || isNotEmpty(websocketConnections) ||
+	       isNotEmpty(mqttConnections);
 }
 
 void AdvSceneSwitcher::on_exportSettings_clicked()
@@ -383,6 +396,7 @@ void AdvSceneSwitcher::CheckFirstTimeSetup()
 		switcher->firstBoot = false;
 		DisplayMessage(
 			obs_module_text("AdvSceneSwitcher.firstBootMessage"));
+		switcher->Start();
 	}
 }
 
@@ -521,21 +535,23 @@ void SwitcherData::SaveGeneralSettings(obs_data_t *obj)
 	cooldown.Save(obj, "cooldown");
 	obs_data_set_bool(obj, "enableCooldown", enableCooldown);
 
-	obs_data_set_bool(obj, "active", sceneColletionStop ? true : !stop);
-	sceneColletionStop = false;
+	obs_data_set_bool(obj, "active", sceneCollectionStop ? true : !stop);
+	sceneCollectionStop = false;
 	obs_data_set_int(obj, "startup_behavior",
 			 static_cast<int>(startupBehavior));
 
 	obs_data_set_int(obj, "autoStartEvent",
 			 static_cast<int>(autoStartEvent));
 
-	obs_data_set_int(obj, "logLevel", static_cast<int>(logLevel));
-	obs_data_set_int(obj, "logLevelVersion", 1);
+	SaveLogLevel(obj);
+
 	obs_data_set_bool(obj, "showSystemTrayNotifications",
 			  showSystemTrayNotifications);
 	obs_data_set_bool(obj, "disableHints", disableHints);
 	obs_data_set_bool(obj, "disableFilterComboboxFilter",
 			  disableFilterComboboxFilter);
+	obs_data_set_bool(obj, "disableMacroWidgetCache",
+			  disableMacroWidgetCache);
 	obs_data_set_bool(obj, "warnPluginLoadFailure", warnPluginLoadFailure);
 	obs_data_set_bool(obj, "hideLegacyTabs", hideLegacyTabs);
 
@@ -586,31 +602,15 @@ void SwitcherData::LoadGeneralSettings(obs_data_t *obj)
 	autoStartEvent =
 		static_cast<AutoStart>(obs_data_get_int(obj, "autoStartEvent"));
 
-	logLevel = static_cast<LogLevel>(obs_data_get_int(obj, "logLevel"));
-	if (obs_data_get_int(obj, "logLevelVersion") < 1) {
-		enum OldLogLevel { DEFAULT, LOG_ACTION, VERBOSE };
-		OldLogLevel oldLogLevel = static_cast<OldLogLevel>(
-			obs_data_get_int(obj, "logLevel"));
-		switch (oldLogLevel) {
-		case DEFAULT:
-			logLevel = LogLevel::DEFAULT;
-			break;
-		case LOG_ACTION:
-			logLevel = LogLevel::LOG_ACTION;
-			break;
-		case VERBOSE:
-			logLevel = LogLevel::VERBOSE;
-			break;
-		default:
-			break;
-		}
-	}
+	LoadLogLevel(obj);
 
 	showSystemTrayNotifications =
 		obs_data_get_bool(obj, "showSystemTrayNotifications");
 	disableHints = obs_data_get_bool(obj, "disableHints");
 	disableFilterComboboxFilter =
 		obs_data_get_bool(obj, "disableFilterComboboxFilter");
+	disableMacroWidgetCache =
+		obs_data_get_bool(obj, "disableMacroWidgetCache");
 	obs_data_set_default_bool(obj, "warnPluginLoadFailure", true);
 	warnPluginLoadFailure = obs_data_get_bool(obj, "warnPluginLoadFailure");
 	obs_data_set_default_bool(obj, "hideLegacyTabs", true);
@@ -894,7 +894,9 @@ void AdvSceneSwitcher::SetupGeneralTab()
 			 SIGNAL(DurationChanged(const Duration &)), this,
 			 SLOT(CooldownDurationChanged(const Duration &)));
 
-	ui->logLevel->setCurrentIndex(static_cast<int>(switcher->logLevel));
+	PopulateLogLevelSelection(ui->logLevel);
+	ui->logLevel->setCurrentIndex(
+		ui->logLevel->findData(static_cast<int>(GetLogLevel())));
 
 	ui->saveWindowGeo->setChecked(switcher->saveWindowGeo);
 	ui->showTrayNotifications->setChecked(
@@ -904,6 +906,9 @@ void AdvSceneSwitcher::SetupGeneralTab()
 		switcher->disableFilterComboboxFilter);
 	FilterComboBox::SetFilterBehaviourEnabled(
 		!switcher->disableFilterComboboxFilter);
+	ui->disableMacroWidgetCache->setChecked(
+		switcher->disableMacroWidgetCache);
+	MacroSegmentList::SetCachingEnabled(!switcher->disableMacroWidgetCache);
 	ui->warnPluginLoadFailure->setChecked(switcher->warnPluginLoadFailure);
 	ui->hideLegacyTabs->setChecked(switcher->hideLegacyTabs);
 
