@@ -1,10 +1,10 @@
 namespace advss {
 
-class AdvSceneSwitcher;
+class MacroEdit;
 
 bool MacroSegmentIsInClipboard();
 bool MacroActionIsInClipboard();
 void SetCopySegmentTargetActionType(bool setToElseAction);
-void SetupSegmentCopyPasteShortcutHandlers(AdvSceneSwitcher *window);
+void SetupSegmentCopyPasteShortcutHandlers(MacroEdit *edit);
 
 } // namespace advss
