@@ -414,6 +414,20 @@ void MacroTreeModel::Add(std::shared_ptr<Macro> item)
 				      QItemSelectionModel::Select);
 }
 
+void MacroTreeModel::MoveToBeginningOfGroup(std::shared_ptr<Macro> item,
+					    std::shared_ptr<Macro> group)
+{
+	auto it = std::find(_macros.begin(), _macros.end(), item);
+	assert(it != _macros.end());
+	std::shared_ptr<Macro> tmp = *it;
+	_macros.erase(it);
+	it = std::find(_macros.begin(), _macros.end(), group);
+	assert(it != _macros.end());
+	_macros.insert(std::next(it), tmp);
+
+	Reset(_macros);
+}
+
 void MacroTreeModel::Remove(std::shared_ptr<Macro> item)
 {
 	auto lock = LockContext();
@@ -789,6 +803,13 @@ void MacroTree::Add(std::shared_ptr<Macro> item,
 	assert(GetModel()->IsInValidState());
 }
 
+void MacroTree::AddToGroup(std::shared_ptr<Macro> item,
+			   std::shared_ptr<Macro> group) const
+{
+	GetModel()->Add(item);
+	GetModel()->MoveToBeginningOfGroup(item, group);
+}
+
 std::shared_ptr<Macro> MacroTree::GetCurrentMacro() const
 {
 	return GetModel()->GetCurrentMacro();
@@ -1160,6 +1181,28 @@ bool MacroTree::SelectionEmpty() const
 	return selectedIndexes().empty();
 }
 
+bool MacroTree::GroupsExist() const
+{
+	for (const auto &macro : GetMacros()) {
+		if (macro->IsGroup()) {
+			return true;
+		}
+	}
+	return false;
+}
+
+void MacroTree::ExpandGroup(std::shared_ptr<Macro> item) const
+{
+	auto *mtm = GetModel();
+	mtm->ExpandGroup(item);
+}
+
+void MacroTree::CollapseGroup(std::shared_ptr<Macro> item) const
+{
+	auto *mtm = GetModel();
+	mtm->CollapseGroup(item);
+}
+
 void MacroTree::MoveItemBefore(const std::shared_ptr<Macro> &item,
 			       const std::shared_ptr<Macro> &after) const
 {
@@ -1260,6 +1303,26 @@ void MacroTree::UngroupSelectedGroups()
 	assert(GetModel()->IsInValidState());
 }
 
+void MacroTree::ExpandAll()
+{
+	for (const auto &macro : GetMacros()) {
+		if (!macro->IsGroup()) {
+			continue;
+		}
+		ExpandGroup(macro);
+	}
+}
+
+void MacroTree::CollapseAll()
+{
+	for (const auto &macro : GetMacros()) {
+		if (!macro->IsGroup()) {
+			continue;
+		}
+		CollapseGroup(macro);
+	}
+}
+
 void MacroTree::SelectionChangedHelper(const QItemSelection &,
 				       const QItemSelection &)
 {
@@ -1301,10 +1364,10 @@ QSize MacroTreeDelegate::sizeHint(const QStyleOptionViewItem &option,
 	QWidget *item = tree->indexWidget(index);
 
 	if (!item) {
-		return (QSize(0, 0));
+		return QStyledItemDelegate::sizeHint(option, index);
 	}
 
-	return (QSize(option.widget->minimumWidth(), item->height()));
+	return QSize(item->sizeHint());
 }
 
 } // namespace advss
