@@ -3,6 +3,7 @@
 #include "macro-condition-factory.hpp"
 #include "macro-dock.hpp"
 #include "macro-helpers.hpp"
+#include "macro-settings.hpp"
 #include "plugin-state-helpers.hpp"
 #include "splitter-helpers.hpp"
 #include "sync-helpers.hpp"
@@ -76,15 +77,21 @@ namespace advss {
 
 static std::deque<std::shared_ptr<Macro>> macros;
 
-Macro::Macro(const std::string &name, const bool addHotkey,
-	     const bool shortCircuitEvaluation)
+Macro::Macro(const std::string &name)
 {
 	SetName(name);
-	if (addHotkey) {
+}
+
+Macro::Macro(const std::string &name, const GlobalMacroSettings &settings)
+	: Macro(name)
+{
+	if (settings._newMacroRegisterHotkeys) {
 		SetupHotkeys();
 	}
-	_registerHotkeys = addHotkey;
-	_useShortCircuitEvaluation = shortCircuitEvaluation;
+	_registerHotkeys = settings._newMacroRegisterHotkeys;
+	_checkInParallel = settings._newMacroCheckInParallel;
+	_useShortCircuitEvaluation =
+		settings._newMacroUseShortCircuitEvaluation;
 }
 
 Macro::~Macro()
@@ -104,7 +111,8 @@ std::shared_ptr<Macro>
 Macro::CreateGroup(const std::string &name,
 		   std::vector<std::shared_ptr<Macro>> &children)
 {
-	auto group = std::make_shared<Macro>(name, false);
+	auto group = std::make_shared<Macro>(name);
+	group->_registerHotkeys = false;
 	for (auto &c : children) {
 		c->SetParent(group);
 	}
@@ -165,7 +173,10 @@ static bool checkCondition(const std::shared_ptr<MacroCondition> &condition)
 	static constexpr auto perfLogThreshold = 300ms;
 
 	const auto startTime = std::chrono::high_resolution_clock::now();
-	const bool conditionMatched = condition->CheckCondition();
+	bool conditionMatched = false;
+	condition->WithLock([&condition, &conditionMatched]() {
+		conditionMatched = condition->CheckCondition();
+	});
 	const auto endTime = std::chrono::high_resolution_clock::now();
 	const auto timeSpent = endTime - startTime;
 
@@ -244,19 +255,52 @@ bool Macro::CheckConditions(bool ignorePause)
 		return false;
 	}
 
-	_stop = false;
-	_matched = false;
-	for (auto &condition : _conditions) {
-		if (!condition) {
-			continue;
-		}
+	const auto checkConditionsTask =
+		[this,
+		 ignorePause](const std::deque<std::shared_ptr<MacroCondition>>
+				      &conditions) {
+			for (auto &condition : conditions) {
+				if (!condition) {
+					continue;
+				}
 
-		if (_paused && !ignorePause) {
-			vblog(LOG_INFO, "Macro %s is paused", _name.c_str());
+				if (_paused && !ignorePause) {
+					vblog(LOG_INFO, "Macro %s is paused",
+					      _name.c_str());
+					return false;
+				}
+
+				_matched = CheckConditionHelper(condition);
+			}
+			return _matched;
+		};
+
+	if (CheckInParallel()) {
+		if (!_conditionCheckFuture.valid()) {
+			_stop = false;
+			_matched = false;
+			_conditionCheckFuture = std::async(
+				std::launch::async,
+				[this, checkConditionsTask]() {
+					// Copy to avoid settings modifications
+					// causing issues
+					const auto conditionsCopy = _conditions;
+					checkConditionsTask(conditionsCopy);
+				});
 			return false;
 		}
-
-		_matched = CheckConditionHelper(condition);
+		if (_conditionCheckFuture.wait_for(std::chrono::seconds(0)) !=
+		    std::future_status::ready) {
+			vblog(LOG_INFO,
+			      "Macro %s still waiting for condition check result",
+			      _name.c_str());
+			return false;
+		}
+		_conditionCheckFuture.get();
+	} else {
+		_stop = false;
+		_matched = false;
+		_matched = checkConditionsTask(_conditions);
 	}
 
 	vblog(LOG_INFO, "Macro %s returned %d", _name.c_str(), _matched);
@@ -273,7 +317,9 @@ bool Macro::CheckConditions(bool ignorePause)
 
 bool Macro::PerformActions(bool match, bool forceParallel, bool ignorePause)
 {
-	if (!_done) {
+	if (_actionRunFuture.valid() &&
+	    _actionRunFuture.wait_for(std::chrono::seconds(0)) !=
+		    std::future_status::ready) {
 		vblog(LOG_INFO, "Macro %s already running", _name.c_str());
 
 		if (!_stopActionsIfNotDone) {
@@ -291,14 +337,15 @@ bool Macro::PerformActions(bool match, bool forceParallel, bool ignorePause)
 		      : std::bind(&Macro::RunElseActions, this,
 				  std::placeholders::_1);
 	_stop = false;
-	_done = false;
 	bool ret = true;
 	if (_runInParallel || forceParallel) {
-		if (_backgroundThread.joinable()) {
-			_backgroundThread.join();
+		if (_actionRunFuture.valid()) {
+			_actionRunFuture.get();
 		}
-		_backgroundThread = std::thread(
-			[this, runFunc, ignorePause] { runFunc(ignorePause); });
+		_actionRunFuture = std::async(std::launch::async,
+					      [this, runFunc, ignorePause] {
+						      runFunc(ignorePause);
+					      });
 	} else {
 		ret = runFunc(ignorePause);
 	}
@@ -336,6 +383,13 @@ bool Macro::ConditionsShouldBeChecked() const
 
 bool Macro::ShouldRunActions() const
 {
+	if (CheckInParallel() && _conditionCheckFuture.valid()) {
+		vblog(LOG_INFO,
+		      "%s not ready to perform actions as condition check is still running",
+		      _name.c_str());
+		return false;
+	}
+
 	const bool hasActionsToExecute =
 		!_paused && (_matched || _elseActions.size() > 0) &&
 		(!_performActionsOnChange || _conditionSateChanged);
@@ -393,9 +447,12 @@ bool Macro::RunActionsHelper(
 		}
 		if (action->Enabled()) {
 			action->LogAction();
+			bool actionResult = false;
+			action->WithLock([&action, &actionResult]() {
+				actionResult = action->PerformAction();
+			});
 			actionsExecutedSuccessfully =
-				actionsExecutedSuccessfully &&
-				action->PerformAction();
+				actionsExecutedSuccessfully && actionResult;
 		} else {
 			vblog(LOG_INFO, "skipping disabled action %s",
 			      action->GetId().c_str());
@@ -408,7 +465,6 @@ bool Macro::RunActionsHelper(
 			action->EnableHighlight();
 		}
 	}
-	_done = true;
 	return actionsExecutedSuccessfully;
 }
 
@@ -508,9 +564,35 @@ void Macro::Stop()
 			t.join();
 		}
 	}
-	if (_backgroundThread.joinable()) {
-		_backgroundThread.join();
+	if (_actionRunFuture.valid()) {
+		_actionRunFuture.get();
 	}
+	if (_conditionCheckFuture.valid()) {
+		_conditionCheckFuture.get();
+	}
+}
+
+void Macro::SetCheckInParallel(bool parallel)
+{
+	_checkInParallel = parallel;
+	_conditionCheckFuture = {};
+}
+
+bool Macro::ParallelTasksCompleted() const
+{
+	// A parallel action run might be triggered by RunInParallel() or the
+	// "Run Macro" button, so checking just for RunInParallel() will not
+	// suffice
+	if (!CheckInParallel() && !_actionRunFuture.valid()) {
+		return true;
+	}
+	if (_actionRunFuture.valid()) {
+		return false;
+	}
+	if (CheckInParallel() && _conditionCheckFuture.valid()) {
+		return false;
+	}
+	return true;
 }
 
 MacroInputVariables Macro::GetInputVariables() const
@@ -648,16 +730,31 @@ std::deque<std::shared_ptr<MacroCondition>> &Macro::Conditions()
 	return _conditions;
 }
 
+const std::deque<std::shared_ptr<MacroCondition>> &Macro::Conditions() const
+{
+	return _conditions;
+}
+
 std::deque<std::shared_ptr<MacroAction>> &Macro::Actions()
 {
 	return _actions;
 }
 
+const std::deque<std::shared_ptr<MacroAction>> &Macro::Actions() const
+{
+	return _actions;
+}
+
 std::deque<std::shared_ptr<MacroAction>> &Macro::ElseActions()
 {
 	return _elseActions;
 }
 
+const std::deque<std::shared_ptr<MacroAction>> &Macro::ElseActions() const
+{
+	return _elseActions;
+}
+
 static void updateIndicesHelper(std::deque<std::shared_ptr<MacroSegment>> &list)
 {
 	int idx = 0;
@@ -712,6 +809,7 @@ bool Macro::Save(obs_data_t *obj, bool saveForCopy) const
 			 static_cast<int>(_pauseSaveBehavior));
 	obs_data_set_bool(obj, "pause", _paused);
 	obs_data_set_bool(obj, "parallel", _runInParallel);
+	obs_data_set_bool(obj, "checkConditionsInParallel", _checkInParallel);
 	obs_data_set_bool(obj, "onChange", _performActionsOnChange);
 	obs_data_set_bool(obj, "skipExecOnStart", _skipExecOnStart);
 	obs_data_set_bool(obj, "stopActionsIfNotDone", _stopActionsIfNotDone);
@@ -797,6 +895,7 @@ bool Macro::Load(obs_data_t *obj)
 		break;
 	}
 	_runInParallel = obs_data_get_bool(obj, "parallel");
+	_checkInParallel = obs_data_get_bool(obj, "checkConditionsInParallel");
 	_performActionsOnChange = obs_data_get_bool(obj, "onChange");
 	_skipExecOnStart = obs_data_get_bool(obj, "skipExecOnStart");
 	_stopActionsIfNotDone = obs_data_get_bool(obj, "stopActionsIfNotDone");
@@ -840,9 +939,12 @@ bool Macro::Load(obs_data_t *obj)
 		auto newEntry = MacroConditionFactory::Create(id, this);
 		if (newEntry) {
 			_conditions.emplace_back(newEntry);
-			auto c = _conditions.back().get();
-			c->Load(arrayObj);
-			c->ValidateLogicSelection(root, Name().c_str());
+			auto condition = _conditions.back().get();
+			condition->WithLock([&]() {
+				condition->Load(arrayObj);
+				condition->ValidateLogicSelection(
+					root, Name().c_str());
+			});
 		} else {
 			blog(LOG_WARNING,
 			     "discarding condition entry with unknown id (%s) for macro %s",
@@ -855,12 +957,15 @@ bool Macro::Load(obs_data_t *obj)
 	OBSDataArrayAutoRelease actions = obs_data_get_array(obj, "actions");
 	count = obs_data_array_count(actions);
 	for (size_t i = 0; i < count; i++) {
-		OBSDataAutoRelease array_obj = obs_data_array_item(actions, i);
-		std::string id = obs_data_get_string(array_obj, "id");
+		OBSDataAutoRelease arrayObj = obs_data_array_item(actions, i);
+		std::string id = obs_data_get_string(arrayObj, "id");
 		auto newEntry = MacroActionFactory::Create(id, this);
 		if (newEntry) {
 			_actions.emplace_back(newEntry);
-			_actions.back()->Load(array_obj);
+			auto action = _actions.back().get();
+			action->WithLock([action, &arrayObj]() {
+				action->Load(arrayObj);
+			});
 		} else {
 			blog(LOG_WARNING,
 			     "discarding action entry with unknown id (%s) for macro %s",
@@ -873,13 +978,16 @@ bool Macro::Load(obs_data_t *obj)
 		obs_data_get_array(obj, "elseActions");
 	count = obs_data_array_count(elseActions);
 	for (size_t i = 0; i < count; i++) {
-		OBSDataAutoRelease array_obj =
+		OBSDataAutoRelease arrayObj =
 			obs_data_array_item(elseActions, i);
-		std::string id = obs_data_get_string(array_obj, "id");
+		std::string id = obs_data_get_string(arrayObj, "id");
 		auto newEntry = MacroActionFactory::Create(id, this);
 		if (newEntry) {
 			_elseActions.emplace_back(newEntry);
-			_elseActions.back()->Load(array_obj);
+			auto action = _elseActions.back().get();
+			action->WithLock([action, &arrayObj]() {
+				action->Load(arrayObj);
+			});
 		} else {
 			blog(LOG_WARNING,
 			     "discarding elseAction entry with unknown id (%s) for macro %s",
@@ -896,13 +1004,13 @@ bool Macro::Load(obs_data_t *obj)
 bool Macro::PostLoad()
 {
 	for (auto &c : _conditions) {
-		c->PostLoad();
+		c->WithLock([c]() { c->PostLoad(); });
 	}
 	for (auto &a : _actions) {
-		a->PostLoad();
+		a->WithLock([a]() { a->PostLoad(); });
 	}
 	for (auto &a : _elseActions) {
-		a->PostLoad();
+		a->WithLock([a]() { a->PostLoad(); });
 	}
 	return true;
 }
@@ -1468,6 +1576,14 @@ std::weak_ptr<Macro> GetWeakMacroByName(const char *name)
 void InvalidateMacroTempVarValues()
 {
 	for (const auto &m : macros) {
+		// Do not invalidate the temp vars set during condition checks
+		// or action executions running in parallel to the "main" macro
+		// loop, as otherwise access to the information stored in those
+		// variables might get lost while those checks or actions are
+		// still ongoing.
+		if (!m->ParallelTasksCompleted()) {
+			continue;
+		}
 		m->InvalidateTempVarValues();
 	}
 }
