@@ -7,6 +7,7 @@
 #include "variable-string.hpp"
 #include "temp-variable.hpp"
 
+#include <future>
 #include <QString>
 #include <QByteArray>
 #include <string>
@@ -20,6 +21,7 @@
 namespace advss {
 
 class MacroDock;
+class GlobalMacroSettings;
 
 class Macro {
 	using TimePoint = std::chrono::high_resolution_clock::time_point;
@@ -27,8 +29,8 @@ class Macro {
 public:
 	enum class PauseStateSaveBehavior { PERSIST, PAUSE, UNPAUSE };
 
-	Macro(const std::string &name = "", const bool addHotkey = false,
-	      const bool shortCircuitEvaluation = false);
+	Macro(const std::string &name = "");
+	Macro(const std::string &name, const GlobalMacroSettings &settings);
 	~Macro();
 
 	std::string Name() const { return _name; }
@@ -77,6 +79,9 @@ public:
 	void AddHelperThread(std::thread &&);
 	void SetRunInParallel(bool parallel) { _runInParallel = parallel; }
 	bool RunInParallel() const { return _runInParallel; }
+	bool CheckInParallel() const { return _checkInParallel; }
+	void SetCheckInParallel(bool parallel);
+	bool ParallelTasksCompleted() const;
 
 	// Input variables
 	MacroInputVariables GetInputVariables() const;
@@ -90,8 +95,11 @@ public:
 
 	// Macro segments
 	std::deque<std::shared_ptr<MacroCondition>> &Conditions();
+	const std::deque<std::shared_ptr<MacroCondition>> &Conditions() const;
 	std::deque<std::shared_ptr<MacroAction>> &Actions();
+	const std::deque<std::shared_ptr<MacroAction>> &Actions() const;
 	std::deque<std::shared_ptr<MacroAction>> &ElseActions();
+	const std::deque<std::shared_ptr<MacroAction>> &ElseActions() const;
 	void UpdateActionIndices();
 	void UpdateElseActionIndices();
 	void UpdateConditionIndices();
@@ -182,11 +190,10 @@ private:
 	std::string _name = "";
 	bool _die = false;
 	bool _stop = false;
-	bool _done = true;
+	std::future<void> _actionRunFuture;
 	TimePoint _lastCheckTime{};
 	TimePoint _lastUnpauseTime{};
 	TimePoint _lastExecutionTime{};
-	std::thread _backgroundThread;
 	std::vector<std::thread> _helperThreads;
 
 	std::deque<std::shared_ptr<MacroCondition>> _conditions;
@@ -204,7 +211,9 @@ private:
 	bool _conditionSateChanged = false;
 
 	bool _runInParallel = false;
+	bool _checkInParallel = false;
 	bool _matched = false;
+	std::future<void> _conditionCheckFuture;
 	bool _lastMatched = false;
 	bool _performActionsOnChange = true;
 	bool _skipExecOnStart = false;
