@@ -255,6 +255,16 @@ static void removeMacroSegmentHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
 	}
 }
 
+static void addNewMacroHotkeyFunc(void *, obs_hotkey_id, obs_hotkey_t *,
+				  bool pressed)
+{
+	if (pressed && SettingsWindowIsOpened()) {
+		QMetaObject::invokeMethod(GetSettingsWindow(),
+					  "on_macroAdd_clicked",
+					  Qt::QueuedConnection);
+	}
+}
+
 static void registerHotkeys()
 {
 	switcher->startHotkey = obs_hotkey_register_frontend(
@@ -270,19 +280,21 @@ static void registerHotkeys()
 		obs_module_text(
 			"AdvSceneSwitcher.hotkey.startStopToggleSwitcherHotkey"),
 		startStopToggleHotkeyFunc, NULL);
+	switcher->newMacroHotkey = obs_hotkey_register_frontend(
+		"newMacroSwitcherHotkey",
+		obs_module_text("AdvSceneSwitcher.hotkey.macro.new"),
+		addNewMacroHotkeyFunc, NULL);
 	switcher->upMacroSegment = obs_hotkey_register_frontend(
 		"upMacroSegmentSwitcherHotkey",
-		obs_module_text("AdvSceneSwitcher.hotkey.upMacroSegmentHotkey"),
+		obs_module_text("AdvSceneSwitcher.hotkey.macro.segment.up"),
 		upMacroSegmentHotkeyFunc, NULL);
 	switcher->downMacroSegment = obs_hotkey_register_frontend(
 		"downMacroSegmentSwitcherHotkey",
-		obs_module_text(
-			"AdvSceneSwitcher.hotkey.downMacroSegmentHotkey"),
+		obs_module_text("AdvSceneSwitcher.hotkey.macro.segment.down"),
 		downMacroSegmentHotkeyFunc, NULL);
 	switcher->removeMacroSegment = obs_hotkey_register_frontend(
 		"removeMacroSegmentSwitcherHotkey",
-		obs_module_text(
-			"AdvSceneSwitcher.hotkey.removeMacroSegmentHotkey"),
+		obs_module_text("AdvSceneSwitcher.hotkey.macro.segment.remove"),
 		removeMacroSegmentHotkeyFunc, NULL);
 
 	switcher->hotkeysRegistered = true;
@@ -300,6 +312,7 @@ void SwitcherData::SaveHotkeys(obs_data_t *obj)
 	saveHotkey(obj, startHotkey, "startHotkey");
 	saveHotkey(obj, stopHotkey, "stopHotkey");
 	saveHotkey(obj, toggleHotkey, "toggleHotkey");
+	saveHotkey(obj, newMacroHotkey, "newMacroHotkey");
 	saveHotkey(obj, upMacroSegment, "upMacroSegmentHotkey");
 	saveHotkey(obj, downMacroSegment, "downMacroSegmentHotkey");
 	saveHotkey(obj, removeMacroSegment, "removeMacroSegmentHotkey");
@@ -312,14 +325,31 @@ static void loadHotkey(obs_data_t *obj, obs_hotkey_id id, const char *name)
 	obs_data_array_release(a);
 }
 
+static void setDefaultHotkeyBinding(obs_data_t *data, const char *name,
+				    const char *value)
+{
+	OBSDataAutoRelease hotkeyData = obs_data_create_from_json(value);
+	OBSDataArrayAutoRelease hotkeyArray = obs_data_array_create();
+	obs_data_array_push_back(hotkeyArray, hotkeyData);
+	obs_data_set_default_array(data, name, hotkeyArray);
+}
+
 void SwitcherData::LoadHotkeys(obs_data_t *obj)
 {
 	if (!hotkeysRegistered) {
 		registerHotkeys();
 	}
+
+	setDefaultHotkeyBinding(obj, "newMacroHotkey",
+				"{"
+				"\"control\": true,"
+				"\"key\": \"OBS_KEY_N\""
+				"}");
+
 	loadHotkey(obj, startHotkey, "startHotkey");
 	loadHotkey(obj, stopHotkey, "stopHotkey");
 	loadHotkey(obj, toggleHotkey, "toggleHotkey");
+	loadHotkey(obj, newMacroHotkey, "newMacroHotkey");
 	loadHotkey(obj, upMacroSegment, "upMacroSegmentHotkey");
 	loadHotkey(obj, downMacroSegment, "downMacroSegmentHotkey");
 	loadHotkey(obj, removeMacroSegment, "removeMacroSegmentHotkey");
