@@ -17,11 +17,7 @@ public:
 		int updateIntervalMs = 300);
 
 protected:
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
 	void enterEvent(QEnterEvent *event) override;
-#else
-	void enterEvent(QEvent *event) override;
-#endif
 	void leaveEvent(QEvent *event) override;
 
 private slots:
