@@ -13,6 +13,7 @@ public:
 	FilterComboBox(QWidget *parent = nullptr,
 		       const QString &placehodler = "");
 	static void SetFilterBehaviourEnabled(bool);
+	void SetAllowUnmatchedSelection(bool allow);
 
 	void setCurrentText(const QString &text);
 	void setItemText(int index, const QString &text);
@@ -27,6 +28,7 @@ private slots:
 private:
 	void Emit(int index, const QString &text);
 
+	bool _allowUnmatchedSelection = false;
 	int _lastEmittedIndex = -1;
 	QString _lastEmittedText;
 
