@@ -272,10 +272,12 @@ TempVariableSelection::TempVariableSelection(QWidget *parent)
 			 SLOT(SelectionIdxChanged(int)));
 	QWidget::connect(_selection, SIGNAL(highlighted(int)), this,
 			 SLOT(HighlightChanged(int)));
-	QWidget::connect(window(), SIGNAL(MacroSegmentOrderChanged()), this,
+	QWidget::connect(GetSettingsWindow(),
+			 SIGNAL(MacroSegmentOrderChanged()), this,
 			 SLOT(MacroSegmentsChanged()));
-	QWidget::connect(window(), SIGNAL(SegmentTempVarsChanged()), this,
-			 SLOT(SegmentTempVarsChanged()));
+	QWidget::connect(GetSettingsWindow(),
+			 SIGNAL(SegmentTempVarsChanged(MacroSegment *)), this,
+			 SLOT(SegmentTempVarsChanged(MacroSegment *)));
 
 	auto layout = new QHBoxLayout();
 	layout->setContentsMargins(0, 0, 0, 0);
@@ -314,9 +316,15 @@ void TempVariableSelection::MacroSegmentsChanged()
 	SetVariable(currentSelection);
 }
 
-void TempVariableSelection::SegmentTempVarsChanged()
+void TempVariableSelection::SegmentTempVarsChanged(MacroSegment *segment)
 {
-	MacroSegmentsChanged();
+	const auto currentSegment = GetSegment();
+	const auto currentMacro = currentSegment ? currentSegment->GetMacro()
+						 : nullptr;
+	const auto changeMacro = segment ? segment->GetMacro() : nullptr;
+	if (currentMacro == changeMacro) {
+		MacroSegmentsChanged();
+	}
 }
 
 void TempVariableSelection::HighlightChanged(int idx)
@@ -327,7 +335,8 @@ void TempVariableSelection::HighlightChanged(int idx)
 
 void TempVariableSelection::PopulateSelection()
 {
-	auto advssWindow = qobject_cast<AdvSceneSwitcher *>(window());
+	auto advssWindow =
+		qobject_cast<AdvSceneSwitcher *>(GetSettingsWindow());
 	if (!advssWindow) {
 		return;
 	}
@@ -360,7 +369,8 @@ void TempVariableSelection::PopulateSelection()
 
 void TempVariableSelection::HighlightSelection(const TempVariableRef &var)
 {
-	auto advssWindow = qobject_cast<AdvSceneSwitcher *>(window());
+	auto advssWindow =
+		qobject_cast<AdvSceneSwitcher *>(GetSettingsWindow());
 	if (!advssWindow) {
 		return;
 	}
@@ -387,7 +397,8 @@ QString TempVariableSelection::SetupInfoLabel()
 {
 	auto currentSelection = _selection->itemData(_selection->currentIndex())
 					.value<TempVariableRef>();
-	auto advssWindow = qobject_cast<AdvSceneSwitcher *>(window());
+	auto advssWindow =
+		qobject_cast<AdvSceneSwitcher *>(GetSettingsWindow());
 	if (!advssWindow) {
 		_info->setToolTip("");
 		_info->hide();
@@ -427,13 +438,11 @@ QString TempVariableSelection::SetupInfoLabel()
 MacroSegment *TempVariableSelection::GetSegment() const
 {
 	const QWidget *widget = this;
-	{
-		while (widget) {
-			if (qobject_cast<const MacroSegmentEdit *>(widget)) {
-				break;
-			}
-			widget = widget->parentWidget();
+	while (widget) {
+		if (qobject_cast<const MacroSegmentEdit *>(widget)) {
+			break;
 		}
+		widget = widget->parentWidget();
 	}
 	if (!widget) {
 		return nullptr;
@@ -442,17 +451,18 @@ MacroSegment *TempVariableSelection::GetSegment() const
 	return segmentWidget->Data().get();
 }
 
-void NotifyUIAboutTempVarChange()
+void NotifyUIAboutTempVarChange(MacroSegment *segment)
 {
 	obs_queue_task(
 		OBS_TASK_UI,
-		[](void *) {
+		[](void *segment) {
 			if (!SettingsWindowIsOpened()) {
 				return;
 			}
-			AdvSceneSwitcher::window->SegmentTempVarsChanged();
+			AdvSceneSwitcher::window->SegmentTempVarsChanged(
+				(MacroSegment *)segment);
 		},
-		nullptr, false);
+		segment, false);
 }
 
 } // namespace advss
