@@ -15,8 +15,6 @@ EXPORT std::pair<int, int> GetCursorPos();
 
 bool ReplaceAll(std::string &str, const std::string &from,
 		const std::string &to);
-EXPORT std::optional<std::string> GetJsonField(const std::string &json,
-					       const std::string &id);
 EXPORT bool CompareIgnoringLineEnding(QString &s1, QString &s2);
 std::string ToString(double value);
 
