@@ -3,6 +3,7 @@
 #include "json-helpers.hpp"
 #include "source-settings-helpers.hpp"
 #include "selection-helpers.hpp"
+#include "ui-helpers.hpp"
 
 namespace advss {
 
@@ -26,10 +27,13 @@ const static std::map<MacroActionFilter::Action, std::string> actionTypes = {
 	 "AdvSceneSwitcher.action.filter.type.pressSettingsButton"},
 };
 
-const static std::map<MacroActionFilter::SettingsInputMethod, std::string>
+const static std::vector<
+	std::pair<MacroActionFilter::SettingsInputMethod, std::string>>
 	inputMethods = {
 		{MacroActionFilter::SettingsInputMethod::INDIVIDUAL_MANUAL,
 		 "AdvSceneSwitcher.action.filter.inputMethod.individualManual"},
+		{MacroActionFilter::SettingsInputMethod::INDIVIDUAL_LIST_ENTRY,
+		 "AdvSceneSwitcher.action.filter.inputMethod.individualListEntryManual"},
 		{MacroActionFilter::SettingsInputMethod::INDIVIDUAL_TEMPVAR,
 		 "AdvSceneSwitcher.action.filter.inputMethod.individualTempvar"},
 		{MacroActionFilter::SettingsInputMethod::JSON_STRING,
@@ -59,6 +63,10 @@ static void performActionHelper(
 		case MacroActionFilter::SettingsInputMethod::INDIVIDUAL_MANUAL:
 			SetSourceSetting(source, setting, manualSettingValue);
 			break;
+		case MacroActionFilter::SettingsInputMethod::INDIVIDUAL_LIST_ENTRY:
+			SetSourceSettingListEntryValueByName(
+				source, setting, manualSettingValue);
+			break;
 		case MacroActionFilter::SettingsInputMethod::INDIVIDUAL_TEMPVAR: {
 			auto var = tempVar.GetTempVariable(macro);
 			if (!var) {
@@ -185,8 +193,8 @@ void MacroActionFilter::ResolveVariablesToFixedValues()
 
 static inline void populateActionSelection(QComboBox *list)
 {
-	for (auto entry : actionTypes) {
-		list->addItem(obs_module_text(entry.second.c_str()));
+	for (const auto &[_, name] : actionTypes) {
+		list->addItem(obs_module_text(name.c_str()));
 	}
 }
 
@@ -199,10 +207,17 @@ static inline void populateSettingsInputMethods(QComboBox *list)
 	}
 }
 
+static QStringList getFilterSourcesList()
+{
+	auto sources = GetSourcesWithFilterNames();
+	sources.sort();
+	return sources;
+}
+
 MacroActionFilterEdit::MacroActionFilterEdit(
 	QWidget *parent, std::shared_ptr<MacroActionFilter> entryData)
 	: QWidget(parent),
-	  _sources(new SourceSelectionWidget(this, QStringList(), true)),
+	  _sources(new SourceSelectionWidget(this, getFilterSourcesList, true)),
 	  _filters(new FilterSelectionWidget(this, _sources, true)),
 	  _actions(new QComboBox()),
 	  _getSettings(new QPushButton(obs_module_text(
@@ -220,9 +235,6 @@ MacroActionFilterEdit::MacroActionFilterEdit(
 	_filters->setSizeAdjustPolicy(QComboBox::AdjustToContents);
 
 	populateActionSelection(_actions);
-	auto sources = GetSourcesWithFilterNames();
-	sources.sort();
-	_sources->SetSourceNameList(sources);
 	_refreshSettingSelection->setToolTip(obs_module_text(
 		"AdvSceneSwitcher.action.filter.refresh.tooltip"));
 
@@ -369,14 +381,25 @@ void MacroActionFilterEdit::GetSettingsClicked()
 				.value_or(""));
 		break;
 	}
+	case MacroActionFilter::SettingsInputMethod::INDIVIDUAL_LIST_ENTRY: {
+		const auto filters =
+			_entryData->_filter.GetFilters(_entryData->_source);
+		_manualSettingValue->setPlainText(
+			GetSourceSettingListEntryName(
+				filters.empty() ? nullptr : filters.at(0),
+				_entryData->_setting)
+				.value_or(""));
+		break;
+	}
 	case MacroActionFilter::SettingsInputMethod::INDIVIDUAL_TEMPVAR:
 		break;
 	case MacroActionFilter::SettingsInputMethod::JSON_STRING: {
 		const auto filters =
 			_entryData->_filter.GetFilters(_entryData->_source);
+		const auto settings = GetSourceSettings(
+			filters.empty() ? nullptr : filters.at(0), true);
 		_settingsString->setPlainText(
-			FormatJsonString(GetSourceSettings(
-				filters.empty() ? nullptr : filters.at(0))));
+			FormatJsonString(settings ? *settings : ""));
 		break;
 	}
 	}
@@ -411,6 +434,7 @@ void MacroActionFilterEdit::SelectionChanged(const SourceSetting &setting)
 {
 	GUARD_LOADING_AND_LOCK();
 	_entryData->_setting = setting;
+	SetWidgetVisibility();
 }
 
 void MacroActionFilterEdit::ManualSettingsValueChanged()
@@ -436,6 +460,22 @@ void MacroActionFilterEdit::ButtonChanged(const SourceSettingButton &button)
 	_entryData->_button = button;
 }
 
+static QString GetIndividualListEntryName()
+{
+	static const auto matchesInput =
+		[](const std::pair<MacroActionFilter::SettingsInputMethod,
+				   std::string> &p) {
+			return p.first ==
+			       MacroActionFilter::SettingsInputMethod::
+				       INDIVIDUAL_LIST_ENTRY;
+		};
+	static const QString listValueText(
+		obs_module_text(std::find_if(inputMethods.begin(),
+					     inputMethods.end(), matchesInput)
+					->second.c_str()));
+	return listValueText;
+}
+
 void MacroActionFilterEdit::SetWidgetVisibility()
 {
 	SetLayoutVisible(_settingsLayout,
@@ -460,9 +500,16 @@ void MacroActionFilterEdit::SetWidgetVisibility()
 				      MacroActionFilter::SettingsInputMethod::
 					      INDIVIDUAL_TEMPVAR);
 
+	SetRowVisibleByValue(_settingsInputMethods,
+			     GetIndividualListEntryName(),
+			     _entryData->_setting.IsList());
+
 	if (_entryData->_action == MacroActionFilter::Action::SETTINGS &&
-	    _entryData->_settingsInputMethod ==
-		    MacroActionFilter::SettingsInputMethod::INDIVIDUAL_MANUAL) {
+	    (_entryData->_settingsInputMethod ==
+		     MacroActionFilter::SettingsInputMethod::INDIVIDUAL_MANUAL ||
+	     _entryData->_settingsInputMethod ==
+		     MacroActionFilter::SettingsInputMethod::
+			     INDIVIDUAL_LIST_ENTRY)) {
 		RemoveStretchIfPresent(_settingsLayout);
 		_manualSettingValue->show();
 	} else {
@@ -471,8 +518,12 @@ void MacroActionFilterEdit::SetWidgetVisibility()
 	}
 
 	_refreshSettingSelection->setVisible(
-		_entryData->_settingsInputMethod ==
-			MacroActionFilter::SettingsInputMethod::INDIVIDUAL_MANUAL &&
+		(_entryData->_settingsInputMethod ==
+			 MacroActionFilter::SettingsInputMethod::
+				 INDIVIDUAL_MANUAL ||
+		 _entryData->_settingsInputMethod ==
+			 MacroActionFilter::SettingsInputMethod::
+				 INDIVIDUAL_LIST_ENTRY) &&
 		(_entryData->_source.GetType() ==
 			 SourceSelection::Type::VARIABLE ||
 		 _entryData->_filter.GetType() ==
