@@ -4,6 +4,10 @@
 
 #include <log-helper.hpp>
 
+#ifdef VERIFY_TIMESTAMPS
+#include "date/tz.h"
+#endif
+
 namespace advss {
 
 using websocketpp::lib::placeholders::_1;
@@ -123,6 +127,11 @@ void EventSub::ClearActiveSubscriptions()
 	_activeSubscriptions.clear();
 }
 
+void EventSub::EnableTimestampValidation(bool enable)
+{
+	_validateTimestamps = enable;
+}
+
 void EventSub::Disconnect()
 {
 	std::lock_guard<std::mutex> lock(_connectMtx);
@@ -187,7 +196,7 @@ static obs_data_t *copyData(const OBSData &data)
 	return obs_data_create_from_json(json);
 }
 
-std::string EventSub::AddEventSubscribtion(std::shared_ptr<TwitchToken> token,
+std::string EventSub::AddEventSubscription(std::shared_ptr<TwitchToken> token,
 					   Subscription subscription)
 {
 	auto eventSub = token->GetEventSub();
@@ -237,15 +246,43 @@ void EventSub::OnOpen(connection_hdl)
 
 static bool isValidTimestamp(const std::string &timestamp)
 {
-	std::tm tm = {};
-	std::istringstream ss(timestamp);
-	ss >> std::get_time(&tm, "%Y-%m-%dT%H:%M:%S.%fZ");
-	auto tp = std::chrono::system_clock::from_time_t(std::mktime(&tm));
-	tp += std::chrono::hours(1); // UTC
-	std::chrono::system_clock::time_point currentTime =
-		std::chrono::system_clock::now();
-	auto diff = currentTime - tp;
-	return diff <= std::chrono::minutes(10);
+#ifdef VERIFY_TIMESTAMPS
+	// Example input: 2023-07-19T14:56:51.634234626Z
+	try {
+		// Discard the nanosecond part
+		static constexpr size_t dotPos = 19;
+		std::string trimmed = timestamp.substr(0, dotPos);
+		auto tzStart = timestamp.find_first_of("Z+-", dotPos);
+		trimmed = timestamp.substr(0, dotPos);
+		if (tzStart != std::string::npos) {
+			trimmed += timestamp.substr(tzStart);
+		}
+
+		std::istringstream in(trimmed);
+		date::sys_time<std::chrono::seconds> parsedTime;
+		in >> date::parse("%FT%TZ", parsedTime);
+		if (in.fail()) {
+			blog(LOG_WARNING, "failed to parse timestamp %s",
+			     timestamp.c_str());
+			return false;
+		}
+
+		auto now = date::zoned_time{date::current_zone(),
+					    std::chrono::system_clock::now()}
+				   .get_sys_time();
+
+		auto duration = now - parsedTime;
+		// Clocks might be off by a bit, so allow negative values also
+		return duration <= std::chrono::minutes(10) &&
+		       duration >= std::chrono::minutes(-1);
+	} catch (const std::exception &e) {
+		blog(LOG_WARNING, "%s: %s", __func__, e.what());
+		return false;
+	}
+#else
+	// Just assume timestamps are always valid
+	return true;
+#endif
 }
 
 bool EventSub::IsValidMessageID(const std::string &id)
@@ -286,9 +323,10 @@ void EventSub::OnMessage(connection_hdl, EventSubWSClient::message_ptr message)
 	OBSDataAutoRelease metadata = obs_data_get_obj(json, "metadata");
 	std::string timestamp =
 		obs_data_get_string(metadata, "message_timestamp");
-	if (!isValidTimestamp(timestamp)) {
+	if (_validateTimestamps && !isValidTimestamp(timestamp)) {
 		blog(LOG_WARNING,
-		     "Discarding Twitch EventSub with invalid timestamp");
+		     "Discarding Twitch EventSub with invalid timestamp %s",
+		     timestamp.c_str());
 		return;
 	}
 	std::string id = obs_data_get_string(metadata, "message_id");
@@ -308,7 +346,7 @@ void EventSub::OnMessage(connection_hdl, EventSubWSClient::message_ptr message)
 	} else if (messageType == "session_reconnect") {
 		HandleReconnect(payloadJson);
 	} else if (messageType == "revocation") {
-		HanldeRevocation(payloadJson);
+		HandleRevocation(payloadJson);
 	} else {
 		vblog(LOG_INFO, "ignoring message of unknown type '%s'",
 		      messageType.c_str());
@@ -354,7 +392,7 @@ void EventSub::HandleReconnect(obs_data_t *data)
 		      "Twitch EventSub reconnecting", ec);
 }
 
-void EventSub::HanldeRevocation(obs_data_t *data)
+void EventSub::HandleRevocation(obs_data_t *data)
 {
 	OBSDataAutoRelease subscription =
 		obs_data_get_obj(data, "subscription");
